"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    studio_id: str,
    type_: str,
    client_token: str = None,
    configuration: Dict = None,
    description: str = None,
    ec2_security_group_ids: List = None,
    initialization_scripts: List = None,
    script_parameters: List = None,
    subtype: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a studio component resource.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        configuration(Dict, optional): The configuration of the studio component, based on component type. Defaults to None.
        description(str, optional): The description. Defaults to None.
        ec2_security_group_ids(List, optional): The EC2 security groups that control access to the studio component. Defaults to None.
        initialization_scripts(List, optional): Initialization scripts for studio components. Defaults to None.
        name(str): The name for the studio component.
        script_parameters(List, optional): Parameters for the studio component scripts. Defaults to None.
        studio_id(str): The studio ID.
        subtype(str, optional): The specific subtype of a studio component. Defaults to None.
        tags(Dict, optional): A collection of labels, in the form of key:value pairs, that apply to this resource. Defaults to None.
        type_(str): The type of the studio component.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.component.create(
                ctx, name=value, studio_id=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.component.create name=value, studio_id=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="create_studio_component",
        op_kwargs={
            "clientToken": client_token,
            "configuration": configuration,
            "description": description,
            "ec2SecurityGroupIds": ec2_security_group_ids,
            "initializationScripts": initialization_scripts,
            "name": name,
            "scriptParameters": script_parameters,
            "studioId": studio_id,
            "subtype": subtype,
            "tags": tags,
            "type": type_,
        },
    )


async def delete(
    hub, ctx, studio_component_id: str, studio_id: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a studio component resource.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        studio_component_id(str): The studio component ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.component.delete(
                ctx, studio_component_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.component.delete studio_component_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="delete_studio_component",
        op_kwargs={
            "clientToken": client_token,
            "studioComponentId": studio_component_id,
            "studioId": studio_id,
        },
    )


async def get(hub, ctx, studio_component_id: str, studio_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a studio component resource.

    Args:
        studio_component_id(str): The studio component ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.component.get(
                ctx, studio_component_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.component.get studio_component_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="get_studio_component",
        op_kwargs={"studioComponentId": studio_component_id, "studioId": studio_id},
    )


async def list_all(
    hub,
    ctx,
    studio_id: str,
    max_results: int = None,
    next_token: str = None,
    states: List = None,
    types: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the StudioComponents in a studio.

    Args:
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        states(List, optional): A list of states. Defaults to None.
        studio_id(str): The studio ID.
        types(List, optional): The types. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.component.list_all(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.component.list_all studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="list_studio_components",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "states": states,
            "studioId": studio_id,
            "types": types,
        },
    )


async def update(
    hub,
    ctx,
    studio_component_id: str,
    studio_id: str,
    client_token: str = None,
    configuration: Dict = None,
    description: str = None,
    ec2_security_group_ids: List = None,
    initialization_scripts: List = None,
    name: str = None,
    script_parameters: List = None,
    subtype: str = None,
    type_: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a studio component resource.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        configuration(Dict, optional): The configuration of the studio component, based on component type. Defaults to None.
        description(str, optional): The description. Defaults to None.
        ec2_security_group_ids(List, optional): The EC2 security groups that control access to the studio component. Defaults to None.
        initialization_scripts(List, optional): Initialization scripts for studio components. Defaults to None.
        name(str, optional): The name for the studio component. Defaults to None.
        script_parameters(List, optional): Parameters for the studio component scripts. Defaults to None.
        studio_component_id(str): The studio component ID.
        studio_id(str): The studio ID.
        subtype(str, optional): The specific subtype of a studio component. Defaults to None.
        type_(str, optional): The type of the studio component. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.component.update(
                ctx, studio_component_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.component.update studio_component_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="update_studio_component",
        op_kwargs={
            "clientToken": client_token,
            "configuration": configuration,
            "description": description,
            "ec2SecurityGroupIds": ec2_security_group_ids,
            "initializationScripts": initialization_scripts,
            "name": name,
            "scriptParameters": script_parameters,
            "studioComponentId": studio_component_id,
            "studioId": studio_id,
            "subtype": subtype,
            "type": type_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, queue_name: str, attributes: Dict = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new standard or FIFO queue. You can pass one or more attributes in the request. Keep the following in mind:   If you don't specify the FifoQueue attribute, Amazon SQS creates a standard queue.  You can't change the queue type after you create it and you can't convert an existing standard queue into a FIFO queue. You must either create a new FIFO queue for your application or delete your existing standard queue and recreate it as a FIFO queue. For more information, see Moving From a Standard Queue to a FIFO Queue in the Amazon SQS Developer Guide.     If you don't provide a value for an attribute, the queue is created with the default value for the attribute.   If you delete a queue, you must wait at least 60 seconds before creating a queue with the same name.   To successfully create a new queue, you must provide a queue name that adheres to the limits related to queues and is unique within the scope of your queues.  After you create a queue, you must wait at least one second after the queue is created to be able to use the queue.  To get the queue URL, use the  GetQueueUrl  action.  GetQueueUrl  requires only the QueueName parameter. be aware of existing queue names:   If you provide the name of an existing queue along with the exact names and values of all the queue's attributes, CreateQueue returns the queue URL for the existing queue.   If the queue name, attribute names, or attribute values don't match an existing queue, CreateQueue returns an error.   Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:  &AttributeName.1=first   &AttributeName.2=second   Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a user name in the Amazon SQS Developer Guide.

    Args:
        queue_name(str): The name of the new queue. The following limits apply to this name:   A queue name can have up to 80 characters.   Valid values: alphanumeric characters, hyphens (-), and underscores (_).   A FIFO queue name must end with the .fifo suffix.   Queue URLs and names are case-sensitive.
        attributes(Dict, optional): A map of attributes with their corresponding values. The following lists the names, descriptions, and values of the special request parameters that the CreateQueue action uses:    DelaySeconds – The length of time, in seconds, for which the delivery of all messages in the queue is delayed. Valid values: An integer from 0 to 900 seconds (15 minutes). Default: 0.     MaximumMessageSize – The limit of how many bytes a message can contain before Amazon SQS rejects it. Valid values: An integer from 1,024 bytes (1 KiB) to 262,144 bytes (256 KiB). Default: 262,144 (256 KiB).     MessageRetentionPeriod – The length of time, in seconds, for which Amazon SQS retains a message. Valid values: An integer from 60 seconds (1 minute) to 1,209,600 seconds (14 days). Default: 345,600 (4 days).     Policy – The queue's policy. A valid Amazon Web Services policy. For more information about policy structure, see Overview of Amazon Web Services IAM Policies in the Amazon IAM User Guide.     ReceiveMessageWaitTimeSeconds – The length of time, in seconds, for which a  ReceiveMessage  action waits for a message to arrive. Valid values: An integer from 0 to 20 (seconds). Default: 0.     RedrivePolicy – The string that includes the parameters for the dead-letter queue functionality of the source queue as a JSON object. For more information about the redrive policy and dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon SQS Developer Guide.    deadLetterTargetArn – The Amazon Resource Name (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of maxReceiveCount is exceeded.    maxReceiveCount – The number of times a message is delivered to the source queue before being moved to the dead-letter queue. When the ReceiveCount for a message exceeds the maxReceiveCount for a queue, Amazon SQS moves the message to the dead-letter-queue.    The dead-letter queue of a FIFO queue must also be a FIFO queue. Similarly, the dead-letter queue of a standard queue must also be a standard queue.     VisibilityTimeout – The visibility timeout for the queue, in seconds. Valid values: An integer from 0 to 43,200 (12 hours). Default: 30. For more information about the visibility timeout, see Visibility Timeout in the Amazon SQS Developer Guide.   The following attributes apply only to server-side-encryption:    KmsMasterKeyId – The ID of an Amazon Web Services managed customer master key (CMK) for Amazon SQS or a custom CMK. For more information, see Key Terms. While the alias of the Amazon Web Services managed CMK for Amazon SQS is always alias/aws/sqs, the alias of a custom CMK can, for example, be alias/MyAlias . For more examples, see KeyId in the Key Management Service API Reference.     KmsDataKeyReusePeriodSeconds – The length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling KMS again. An integer representing seconds, between 60 seconds (1 minute) and 86,400 seconds (24 hours). Default: 300 (5 minutes). A shorter time period provides better security but results in more calls to KMS which might incur charges after Free Tier. For more information, see How Does the Data Key Reuse Period Work?.    The following attributes apply only to FIFO (first-in-first-out) queues:    FifoQueue – Designates a queue as FIFO. Valid values are true and false. If you don't specify the FifoQueue attribute, Amazon SQS creates a standard queue. You can provide this attribute only during queue creation. You can't change it for an existing queue. When you set this attribute, you must also provide the MessageGroupId for your messages explicitly. For more information, see FIFO queue logic in the Amazon SQS Developer Guide.    ContentBasedDeduplication – Enables content-based deduplication. Valid values are true and false. For more information, see Exactly-once processing in the Amazon SQS Developer Guide. Note the following:    Every message must have a unique MessageDeduplicationId.   You may provide a MessageDeduplicationId explicitly.   If you aren't able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message).    If you don't provide a MessageDeduplicationId and the queue doesn't have ContentBasedDeduplication set, the action fails with an error.   If the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.     When ContentBasedDeduplication is in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered.   If you send one message with ContentBasedDeduplication enabled and then another message with a MessageDeduplicationId that is the same as the one generated for the first MessageDeduplicationId, the two messages are treated as duplicates and only one copy of the message is delivered.      The following attributes apply only to high throughput for FIFO queues:    DeduplicationScope – Specifies whether message deduplication occurs at the message group or queue level. Valid values are messageGroup and queue.    FifoThroughputLimit – Specifies whether the FIFO queue throughput quota applies to the entire queue or per message group. Valid values are perQueue and perMessageGroupId. The perMessageGroupId value is allowed only when the value for DeduplicationScope is messageGroup.   To enable high throughput for FIFO queues, do the following:   Set DeduplicationScope to messageGroup.   Set FifoThroughputLimit to perMessageGroupId.   If you set these attributes to anything other than the values shown for enabling high throughput, normal throughput is in effect and deduplication occurs as specified. For information on throughput quotas, see Quotas related to messages in the Amazon SQS Developer Guide. Defaults to None.
        tags(Dict, optional): Add cost allocation tags to the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide. When you use queue tags, keep the following guidelines in mind:   Adding more than 50 tags to a queue isn't recommended.   Tags don't have any semantic meaning. Amazon SQS interprets tags as character strings.   Tags are case-sensitive.   A new tag with a key identical to that of an existing tag overwrites the existing tag.   For a full list of tag restrictions, see Quotas related to queues in the Amazon SQS Developer Guide.  To be able to tag a queue on creation, you must have the sqs:CreateQueue and sqs:TagQueue permissions. Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a user name in the Amazon SQS Developer Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.init.create(ctx, queue_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.init.create queue_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="create_queue",
        op_kwargs={"QueueName": queue_name, "Attributes": attributes, "tags": tags},
    )


async def delete(hub, ctx, queue_url: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the queue specified by the QueueUrl, regardless of the queue's contents.  Be careful with the DeleteQueue action: When you delete a queue, any messages in the queue are no longer available.   When you delete a queue, the deletion process takes up to 60 seconds. Requests you send involving that queue during the 60 seconds might succeed. For example, a  SendMessage  request might succeed, but after 60 seconds the queue and the message you sent no longer exist. When you delete a queue, you must wait at least 60 seconds before creating a queue with the same name.  Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a user name in the Amazon SQS Developer Guide.

    Args:
        queue_url(str): The URL of the Amazon SQS queue to delete. Queue URLs and names are case-sensitive.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.init.delete(ctx, queue_url=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.init.delete queue_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="delete_queue",
        op_kwargs={"QueueUrl": queue_url},
    )


async def list_all(
    hub,
    ctx,
    queue_name_prefix: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of your queues in the current region. The response includes a maximum of 1,000 results. If you specify a value for the optional QueueNamePrefix parameter, only queues with a name that begins with the specified value are returned.  The listQueues methods supports pagination. Set parameter MaxResults in the request to specify the maximum number of results to be returned in the response. If you do not set MaxResults, the response includes a maximum of 1,000 results. If you set MaxResults and there are additional results to display, the response includes a value for NextToken. Use NextToken as a parameter in your next request to listQueues to receive the next page of results.   Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a user name in the Amazon SQS Developer Guide.

    Args:
        queue_name_prefix(str, optional): A string to use for filtering the list results. Only those queues whose name begins with the specified string are returned. Queue URLs and names are case-sensitive. Defaults to None.
        next_token(str, optional): Pagination token to request the next set of results. Defaults to None.
        max_results(int, optional): Maximum number of results to include in the response. Value range is 1 to 1000. You must set MaxResults to receive a value for NextToken in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="list_queues",
        op_kwargs={
            "QueueNamePrefix": queue_name_prefix,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def purge(hub, ctx, queue_url: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the messages in a queue specified by the QueueURL parameter.  When you use the PurgeQueue action, you can't retrieve any messages deleted from a queue. The message deletion process takes up to 60 seconds. We recommend waiting for 60 seconds regardless of your queue's size.   Messages sent to the queue before you call PurgeQueue might be received but are deleted within the next minute. Messages sent to the queue after you call PurgeQueue might be deleted while the queue is being purged.

    Args:
        queue_url(str): The URL of the queue from which the PurgeQueue action deletes messages. Queue URLs and names are case-sensitive.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.init.purge(ctx, queue_url=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.init.purge queue_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="purge_queue",
        op_kwargs={"QueueUrl": queue_url},
    )


async def tag(hub, ctx, queue_url: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Add cost allocation tags to the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide. When you use queue tags, keep the following guidelines in mind:   Adding more than 50 tags to a queue isn't recommended.   Tags don't have any semantic meaning. Amazon SQS interprets tags as character strings.   Tags are case-sensitive.   A new tag with a key identical to that of an existing tag overwrites the existing tag.   For a full list of tag restrictions, see Quotas related to queues in the Amazon SQS Developer Guide.  Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a user name in the Amazon SQS Developer Guide.

    Args:
        queue_url(str): The URL of the queue.
        tags(Dict): The list of tags to be added to the specified queue.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.init.tag(ctx, queue_url=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.init.tag queue_url=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="tag_queue",
        op_kwargs={"QueueUrl": queue_url, "Tags": tags},
    )


async def untag(hub, ctx, queue_url: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Remove cost allocation tags from the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide.  Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a user name in the Amazon SQS Developer Guide.

    Args:
        queue_url(str): The URL of the queue.
        tag_keys(List): The list of tags to be removed from the specified queue.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.init.untag(ctx, queue_url=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.init.untag queue_url=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="untag_queue",
        op_kwargs={"QueueUrl": queue_url, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    test_id: str = None,
    virtual_interface_id: str = None,
    bgp_peers: List = None,
    status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the virtual interface failover test history.

    Args:
        test_id(str, optional): The ID of the virtual interface failover test. Defaults to None.
        virtual_interface_id(str, optional): The ID of the virtual interface that was tested. Defaults to None.
        bgp_peers(List, optional): The BGP peers that were placed in the DOWN state during the virtual interface failover test. Defaults to None.
        status(str, optional): The status of the virtual interface failover test. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. If MaxResults is given a value larger than 100, only 100 results are returned. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.virtual.interface.test_history.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.virtual.interface.test_history.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="list_virtual_interface_test_history",
        op_kwargs={
            "testId": test_id,
            "virtualInterfaceId": virtual_interface_id,
            "bgpPeers": bgp_peers,
            "status": status,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the Amazon Macie configuration settings for an Amazon Web Services organization.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.organization.configuration.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.organization.configuration.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="describe_organization_configuration",
        op_kwargs={},
    )


async def update(hub, ctx, auto_enable: bool) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Amazon Macie configuration settings for an Amazon Web Services organization.

    Args:
        auto_enable(bool): Specifies whether to enable Amazon Macie automatically for each account, when the account is added to the Amazon Web Services organization.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.organization.configuration.update(ctx, auto_enable=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.organization.configuration.update auto_enable=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="update_organization_configuration",
        op_kwargs={"autoEnable": auto_enable},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def delete(hub, ctx, target_type: str, target_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a logging level.

    Args:
        target_type(str): The type of resource for which you are configuring logging. Must be THING_Group.
        target_name(str): The name of the resource for which you are configuring logging.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.v2_logging.level.delete(
                ctx, target_type=value, target_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.v2_logging.level.delete target_type=value, target_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_v2_logging_level",
        op_kwargs={"targetType": target_type, "targetName": target_name},
    )


async def list_all(
    hub, ctx, target_type: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists logging levels.

    Args:
        target_type(str, optional): The type of resource for which you are configuring logging. Must be THING_Group. Defaults to None.
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.v2_logging.level.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.v2_logging.level.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_v2_logging_levels",
        op_kwargs={
            "targetType": target_type,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def set_(hub, ctx, log_target: Dict, log_level: str) -> None:
    r"""
    **Autogenerated function**

    Sets the logging level.

    Args:
        log_target(Dict): The log target.
        log_level(str): The log level.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.v2_logging.level.set(ctx, log_target=value, log_level=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.v2_logging.level.set log_target=value, log_level=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="set_v2_logging_level",
        op_kwargs={"logTarget": log_target, "logLevel": log_level},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def invoke(
    hub,
    ctx,
    workbook_id: str,
    app_id: str,
    screen_id: str,
    screen_automation_id: str,
    variables: Dict = None,
    row_id: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The InvokeScreenAutomation API allows invoking an action defined in a screen in a Honeycode app. The API allows setting local variables, which can then be used in the automation being invoked. This allows automating the Honeycode app interactions to write, update or delete data in the workbook.

    Args:
        workbook_id(str): The ID of the workbook that contains the screen automation.
        app_id(str): The ID of the app that contains the screen automation.
        screen_id(str): The ID of the screen that contains the screen automation.
        screen_automation_id(str): The ID of the automation action to be performed.
        variables(Dict, optional):  Variables are specified as a map where the key is the name of the variable as defined on the screen. The value is an object which currently has only one property, rawValue, which holds the value of the variable to be passed to the screen. Any variables defined in a screen are required to be passed in the call. . Defaults to None.
        row_id(str, optional):  The row ID for the automation if the automation is defined inside a block with source or list. . Defaults to None.
        client_request_token(str, optional):  The request token for performing the automation action. Request tokens help to identify duplicate requests. If a call times out or fails due to a transient error like a failed network connection, you can retry the call with the same request token. The service ensures that if the first call using that request token is successfully performed, the second call will return the response of the previous call rather than performing the action again.   Note that request tokens are valid only for a few minutes. You cannot use request tokens to dedupe requests spanning hours or days. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.screen.automation.invoke(
                ctx, workbook_id=value, app_id=value, screen_id=value, screen_automation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.screen.automation.invoke workbook_id=value, app_id=value, screen_id=value, screen_automation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="invoke_screen_automation",
        op_kwargs={
            "workbookId": workbook_id,
            "appId": app_id,
            "screenId": screen_id,
            "screenAutomationId": screen_automation_id,
            "variables": variables,
            "rowId": row_id,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, gateway_arn: str, marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of virtual tape recovery points that are available for the specified tape gateway. A recovery point is a point-in-time view of a virtual tape at which all the data on the virtual tape is consistent. If your gateway crashes, virtual tapes that have recovery points can be recovered to a new gateway. This operation is only supported in the tape gateway type.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        marker(str, optional): An opaque string that indicates the position at which to begin describing the virtual tape recovery points. Defaults to None.
        limit(int, optional): Specifies that the number of virtual tape recovery points that are described be limited to the specified number. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.recovery_point.describe_all(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.recovery_point.describe_all gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_tape_recovery_points",
        op_kwargs={"GatewayARN": gateway_arn, "Marker": marker, "Limit": limit},
    )


async def retrieve(hub, ctx, tape_arn: str, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the recovery point for the specified virtual tape. This operation is only supported in the tape gateway type. A recovery point is a point in time view of a virtual tape at which all the data on the tape is consistent. If your gateway crashes, virtual tapes that have recovery points can be recovered to a new gateway.  The virtual tape can be retrieved to only one gateway. The retrieved tape is read-only. The virtual tape can be retrieved to only a tape gateway. There is no charge for retrieving recovery points.

    Args:
        tape_arn(str): The Amazon Resource Name (ARN) of the virtual tape for which you want to retrieve the recovery point.
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.recovery_point.retrieve(
                ctx, tape_arn=value, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.recovery_point.retrieve tape_arn=value, gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="retrieve_tape_recovery_point",
        op_kwargs={"TapeARN": tape_arn, "GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub,
    ctx,
    profile_id: str,
    profile_object_unique_key: str,
    object_type_name: str,
    domain_name: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Removes an object associated with a profile of a given ProfileObjectType.

    Args:
        profile_id(str): The unique identifier of a customer profile.
        profile_object_unique_key(str): The unique identifier of the profile object generated by the service.
        object_type_name(str): The name of the profile object type.
        domain_name(str): The unique name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.object_.init.delete(
                ctx,
                profile_id=value,
                profile_object_unique_key=value,
                object_type_name=value,
                domain_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.object_.init.delete profile_id=value, profile_object_unique_key=value, object_type_name=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="delete_profile_object",
        op_kwargs={
            "ProfileId": profile_id,
            "ProfileObjectUniqueKey": profile_object_unique_key,
            "ObjectTypeName": object_type_name,
            "DomainName": domain_name,
        },
    )


async def list_all(
    hub,
    ctx,
    domain_name: str,
    object_type_name: str,
    profile_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of objects associated with a profile of a given ProfileObjectType.

    Args:
        next_token(str, optional): The pagination token from the previous call to ListProfileObjects. Defaults to None.
        max_results(int, optional): The maximum number of objects returned per page. Defaults to None.
        domain_name(str): The unique name of the domain.
        object_type_name(str): The name of the profile object type.
        profile_id(str): The unique identifier of a customer profile.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.object_.init.list_all(
                ctx, domain_name=value, object_type_name=value, profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.object_.init.list_all domain_name=value, object_type_name=value, profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="list_profile_objects",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "DomainName": domain_name,
            "ObjectTypeName": object_type_name,
            "ProfileId": profile_id,
        },
    )


async def put(hub, ctx, object_type_name: str, object_: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds additional objects to customer profiles of a given ObjectType. When adding a specific profile object, like a Contact Trace Record (CTR), an inferred profile can get created if it is not mapped to an existing profile. The resulting profile will only have a phone number populated in the standard ProfileObject. Any additional CTRs with the same phone number will be mapped to the same inferred profile. When a ProfileObject is created and if a ProfileObjectType already exists for the ProfileObject, it will provide data to a standard profile depending on the ProfileObjectType definition. PutProfileObject needs an ObjectType, which can be created using PutProfileObjectType.

    Args:
        object_type_name(str): The name of the profile object type.
        object_(str): A string that is serialized from a JSON object.
        domain_name(str): The unique name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.object_.init.put(
                ctx, object_type_name=value, object_=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.object_.init.put object_type_name=value, object_=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="put_profile_object",
        op_kwargs={
            "ObjectTypeName": object_type_name,
            "Object": object_,
            "DomainName": domain_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def remove(hub, ctx, group_name: str, user_name: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified user from the specified group.

    Args:
        group_name(str): The name of the group to update. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        user_name(str): The name of the user to remove. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.from_group.remove(
                ctx, group_name=value, user_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.from_group.remove group_name=value, user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="remove_user_from_group",
        op_kwargs={"GroupName": group_name, "UserName": user_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, global_table_name: str, replication_group: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates a global table from an existing table. A global table creates a replication relationship between two or more DynamoDB tables with the same table name in the provided Regions.   This operation only applies to Version 2017.11.29 of global tables.  If you want to add a new replica table to a global table, each of the following conditions must be true:   The table must have the same primary key as all of the other replicas.   The table must have the same name as all of the other replicas.   The table must have DynamoDB Streams enabled, with the stream containing both the new and the old images of the item.   None of the replica tables in the global table can contain any data.    If global secondary indexes are specified, then the following conditions must also be met:     The global secondary indexes must have the same name.     The global secondary indexes must have the same hash key and sort key (if present).     If local secondary indexes are specified, then the following conditions must also be met:     The local secondary indexes must have the same name.     The local secondary indexes must have the same hash key and sort key (if present).      Write capacity settings should be set consistently across your replica tables and secondary indexes. DynamoDB strongly recommends enabling auto scaling to manage the write capacity settings for all of your global tables replicas and indexes.   If you prefer to manage write capacity settings manually, you should provision equal replicated write capacity units to your replica tables. You should also provision equal replicated write capacity units to matching secondary indexes across your global table.

    Args:
        global_table_name(str): The global table name.
        replication_group(List): The Regions where the global table needs to be created.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.global_table.init.create(
                ctx, global_table_name=value, replication_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.global_table.init.create global_table_name=value, replication_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="create_global_table",
        op_kwargs={
            "GlobalTableName": global_table_name,
            "ReplicationGroup": replication_group,
        },
    )


async def describe(hub, ctx, global_table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified global table.  This operation only applies to Version 2017.11.29 of global tables. If you are using global tables Version 2019.11.21 you can use DescribeTable instead.

    Args:
        global_table_name(str): The name of the global table.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.global_table.init.describe(
                ctx, global_table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.global_table.init.describe global_table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="describe_global_table",
        op_kwargs={"GlobalTableName": global_table_name},
    )


async def list_all(
    hub,
    ctx,
    exclusive_start_global_table_name: str = None,
    limit: int = None,
    region_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all global tables that have a replica in the specified Region.  This operation only applies to Version 2017.11.29 of global tables.

    Args:
        exclusive_start_global_table_name(str, optional): The first global table name that this operation will evaluate. Defaults to None.
        limit(int, optional): The maximum number of table names to return, if the parameter is not specified DynamoDB defaults to 100. If the number of global tables DynamoDB finds reaches this limit, it stops the operation and returns the table names collected up to that point, with a table name in the LastEvaluatedGlobalTableName to apply in a subsequent operation to the ExclusiveStartGlobalTableName parameter. Defaults to None.
        region_name(str, optional): Lists the global tables in a specific Region. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.global_table.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.global_table.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="list_global_tables",
        op_kwargs={
            "ExclusiveStartGlobalTableName": exclusive_start_global_table_name,
            "Limit": limit,
            "RegionName": region_name,
        },
    )


async def update(hub, ctx, global_table_name: str, replica_updates: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds or removes replicas in the specified global table. The global table must already exist to be able to use this operation. Any replica to be added must be empty, have the same name as the global table, have the same key schema, have DynamoDB Streams enabled, and have the same provisioned and maximum write capacity units.  Although you can use UpdateGlobalTable to add replicas and remove replicas in a single request, for simplicity we recommend that you issue separate requests for adding or removing replicas.   If global secondary indexes are specified, then the following conditions must also be met:     The global secondary indexes must have the same name.     The global secondary indexes must have the same hash key and sort key (if present).     The global secondary indexes must have the same provisioned and maximum write capacity units.

    Args:
        global_table_name(str): The global table name.
        replica_updates(List): A list of Regions that should be added or removed from the global table.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.global_table.init.update(
                ctx, global_table_name=value, replica_updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.global_table.init.update global_table_name=value, replica_updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="update_global_table",
        op_kwargs={
            "GlobalTableName": global_table_name,
            "ReplicaUpdates": replica_updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    job_name: str,
    solution_version_arn: str,
    job_input: Dict,
    job_output: Dict,
    role_arn: str,
    filter_arn: str = None,
    num_results: int = None,
    batch_inference_job_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a batch inference job. The operation can handle up to 50 million records and the input file must be in JSON format. For more information, see recommendations-batch.

    Args:
        job_name(str): The name of the batch inference job to create.
        solution_version_arn(str): The Amazon Resource Name (ARN) of the solution version that will be used to generate the batch inference recommendations.
        filter_arn(str, optional): The ARN of the filter to apply to the batch inference job. For more information on using filters, see Filtering Batch Recommendations.. Defaults to None.
        num_results(int, optional): The number of recommendations to retreive. Defaults to None.
        job_input(Dict): The Amazon S3 path that leads to the input file to base your recommendations on. The input material must be in JSON format.
        job_output(Dict): The path to the Amazon S3 bucket where the job's output will be stored.
        role_arn(str): The ARN of the Amazon Identity and Access Management role that has permissions to read and write to your input and output Amazon S3 buckets respectively.
        batch_inference_job_config(Dict, optional): The configuration details of a batch inference job. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.batch_inference_job.create(
                ctx,
                job_name=value,
                solution_version_arn=value,
                job_input=value,
                job_output=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.batch_inference_job.create job_name=value, solution_version_arn=value, job_input=value, job_output=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="create_batch_inference_job",
        op_kwargs={
            "jobName": job_name,
            "solutionVersionArn": solution_version_arn,
            "filterArn": filter_arn,
            "numResults": num_results,
            "jobInput": job_input,
            "jobOutput": job_output,
            "roleArn": role_arn,
            "batchInferenceJobConfig": batch_inference_job_config,
        },
    )


async def describe(hub, ctx, batch_inference_job_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties of a batch inference job including name, Amazon Resource Name (ARN), status, input and output configurations, and the ARN of the solution version used to generate the recommendations.

    Args:
        batch_inference_job_arn(str): The ARN of the batch inference job to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.batch_inference_job.describe(
                ctx, batch_inference_job_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.batch_inference_job.describe batch_inference_job_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_batch_inference_job",
        op_kwargs={"batchInferenceJobArn": batch_inference_job_arn},
    )


async def list_all(
    hub,
    ctx,
    solution_version_arn: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the batch inference jobs that have been performed off of a solution version.

    Args:
        solution_version_arn(str, optional): The Amazon Resource Name (ARN) of the solution version from which the batch inference jobs were created. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of batch inference job results to return in each page. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.batch_inference_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.batch_inference_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="list_batch_inference_jobs",
        op_kwargs={
            "solutionVersionArn": solution_version_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    database: str,
    query_string: str,
    description: str = None,
    client_request_token: str = None,
    work_group: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a named query in the specified workgroup. Requires that you have access to the workgroup. For code samples using the AWS SDK for Java, see Examples and Code Samples in the Amazon Athena User Guide.

    Args:
        name(str): The query name.
        description(str, optional): The query description. Defaults to None.
        database(str): The database to which the query belongs.
        query_string(str): The contents of the query with all query statements.
        client_request_token(str, optional): A unique case-sensitive string used to ensure the request to create the query is idempotent (executes only once). If another CreateNamedQuery request is received, the same response is returned and another query is not created. If a parameter has changed, for example, the QueryString, an error is returned.  This token is listed as not required because AWS SDKs (for example the AWS SDK for Java) auto-generate the token for users. If you are not using the AWS SDK or the AWS CLI, you must provide this token or the action will fail. . Defaults to None.
        work_group(str, optional): The name of the workgroup in which the named query is being created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.named_query.create(
                ctx, name=value, database=value, query_string=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.named_query.create name=value, database=value, query_string=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="create_named_query",
        op_kwargs={
            "Name": name,
            "Description": description,
            "Database": database,
            "QueryString": query_string,
            "ClientRequestToken": client_request_token,
            "WorkGroup": work_group,
        },
    )


async def delete(hub, ctx, named_query_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the named query if you have access to the workgroup in which the query was saved. For code samples using the AWS SDK for Java, see Examples and Code Samples in the Amazon Athena User Guide.

    Args:
        named_query_id(str): The unique ID of the query to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.named_query.delete(ctx, named_query_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.named_query.delete named_query_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="delete_named_query",
        op_kwargs={"NamedQueryId": named_query_id},
    )


async def get(hub, ctx, named_query_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a single query. Requires that you have access to the workgroup in which the query was saved.

    Args:
        named_query_id(str): The unique ID of the query. Use ListNamedQueries to get query IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.named_query.get(ctx, named_query_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.named_query.get named_query_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="get_named_query",
        op_kwargs={"NamedQueryId": named_query_id},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, work_group: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of available query IDs only for queries saved in the specified workgroup. Requires that you have access to the specified workgroup. If a workgroup is not specified, lists the saved queries for the primary workgroup. For code samples using the AWS SDK for Java, see Examples and Code Samples in the Amazon Athena User Guide.

    Args:
        next_token(str, optional): A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call. Defaults to None.
        max_results(int, optional): The maximum number of queries to return in this request. Defaults to None.
        work_group(str, optional): The name of the workgroup from which the named queries are being returned. If a workgroup is not specified, the saved queries for the primary workgroup are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.named_query.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.named_query.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="list_named_queries",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "WorkGroup": work_group,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def delete(hub, ctx, repository_name: str, registry_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the repository policy associated with the specified repository.

    Args:
        registry_id(str, optional): The AWS account ID associated with the public registry that contains the repository policy to delete. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The name of the repository that is associated with the repository policy to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.repository.policy.delete(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.repository.policy.delete repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="delete_repository_policy",
        op_kwargs={"registryId": registry_id, "repositoryName": repository_name},
    )


async def get(hub, ctx, repository_name: str, registry_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the repository policy for the specified repository.

    Args:
        registry_id(str, optional): The AWS account ID associated with the public registry that contains the repository. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The name of the repository with the policy to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.repository.policy.get(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.repository.policy.get repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="get_repository_policy",
        op_kwargs={"registryId": registry_id, "repositoryName": repository_name},
    )


async def set_(
    hub,
    ctx,
    repository_name: str,
    policy_text: str,
    registry_id: str = None,
    force: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Applies a repository policy to the specified public repository to control access permissions. For more information, see Amazon ECR Repository Policies in the Amazon Elastic Container Registry User Guide.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The name of the repository to receive the policy.
        policy_text(str): The JSON repository policy text to apply to the repository. For more information, see Amazon ECR Repository Policies in the Amazon Elastic Container Registry User Guide.
        force(bool, optional): If the policy you are attempting to set on a repository policy would prevent you from setting another policy in the future, you must force the SetRepositoryPolicy operation. This is intended to prevent accidental repository lock outs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.repository.policy.set(
                ctx, repository_name=value, policy_text=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.repository.policy.set repository_name=value, policy_text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="set_repository_policy",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "policyText": policy_text,
            "force": force,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    hsm_configuration_identifier: str,
    description: str,
    hsm_ip_address: str,
    hsm_partition_name: str,
    hsm_partition_password: str,
    hsm_server_public_certificate: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an HSM configuration that contains the information required by an Amazon Redshift cluster to store and use database encryption keys in a Hardware Security Module (HSM). After creating the HSM configuration, you can specify it as a parameter when creating a cluster. The cluster will then store its encryption keys in the HSM. In addition to creating an HSM configuration, you must also create an HSM client certificate. For more information, go to Hardware Security Modules in the Amazon Redshift Cluster Management Guide.

    Args:
        hsm_configuration_identifier(str): The identifier to be assigned to the new Amazon Redshift HSM configuration.
        description(str): A text description of the HSM configuration to be created.
        hsm_ip_address(str): The IP address that the Amazon Redshift cluster must use to access the HSM.
        hsm_partition_name(str): The name of the partition in the HSM where the Amazon Redshift clusters will store their database encryption keys.
        hsm_partition_password(str): The password required to access the HSM partition.
        hsm_server_public_certificate(str): The HSMs public certificate file. When using Cloud HSM, the file name is server.pem.
        tags(List, optional): A list of tag instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.hsm.configuration.create(
                ctx,
                hsm_configuration_identifier=value,
                description=value,
                hsm_ip_address=value,
                hsm_partition_name=value,
                hsm_partition_password=value,
                hsm_server_public_certificate=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.hsm.configuration.create hsm_configuration_identifier=value, description=value, hsm_ip_address=value, hsm_partition_name=value, hsm_partition_password=value, hsm_server_public_certificate=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_hsm_configuration",
        op_kwargs={
            "HsmConfigurationIdentifier": hsm_configuration_identifier,
            "Description": description,
            "HsmIpAddress": hsm_ip_address,
            "HsmPartitionName": hsm_partition_name,
            "HsmPartitionPassword": hsm_partition_password,
            "HsmServerPublicCertificate": hsm_server_public_certificate,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, hsm_configuration_identifier: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified Amazon Redshift HSM configuration.

    Args:
        hsm_configuration_identifier(str): The identifier of the Amazon Redshift HSM configuration to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.hsm.configuration.delete(
                ctx, hsm_configuration_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.hsm.configuration.delete hsm_configuration_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_hsm_configuration",
        op_kwargs={"HsmConfigurationIdentifier": hsm_configuration_identifier},
    )


async def describe_all(
    hub,
    ctx,
    hsm_configuration_identifier: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified Amazon Redshift HSM configuration. If no configuration ID is specified, returns information about all the HSM configurations owned by your Amazon Web Services account. If you specify both tag keys and tag values in the same request, Amazon Redshift returns all HSM connections that match any combination of the specified keys and values. For example, if you have owner and environment for tag keys, and admin and test for tag values, all HSM connections that have any combination of those values are returned. If both tag keys and values are omitted from the request, HSM connections are returned regardless of whether they have tag keys or values associated with them.

    Args:
        hsm_configuration_identifier(str, optional): The identifier of a specific Amazon Redshift HSM configuration to be described. If no identifier is specified, information is returned for all HSM configurations owned by your Amazon Web Services account. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeHsmConfigurations request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching HSM configurations that are associated with the specified key or keys. For example, suppose that you have HSM configurations that are tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the HSM configurations that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching HSM configurations that are associated with the specified tag value or values. For example, suppose that you have HSM configurations that are tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with the HSM configurations that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.hsm.configuration.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.hsm.configuration.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_hsm_configurations",
        op_kwargs={
            "HsmConfigurationIdentifier": hsm_configuration_identifier,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    check_name: str,
    resource_identifier: Dict,
    client_request_token: str,
    expiration_date: str = None,
    suppress_indefinitely: bool = None,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a Device Defender audit suppression.

    Args:
        check_name(str): An audit check name. Checks must be enabled for your account. (Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or use UpdateAccountAuditConfiguration to select which checks are enabled.).
        resource_identifier(Dict): Information that identifies the noncompliant resource.
        expiration_date(str, optional):  The epoch timestamp in seconds at which this suppression expires. . Defaults to None.
        suppress_indefinitely(bool, optional):  Indicates whether a suppression should exist indefinitely or not. . Defaults to None.
        description(str, optional):  The description of the audit suppression. . Defaults to None.
        client_request_token(str):  The epoch timestamp in seconds at which this suppression expires. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.suppression.create(
                ctx, check_name=value, resource_identifier=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.suppression.create check_name=value, resource_identifier=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_audit_suppression",
        op_kwargs={
            "checkName": check_name,
            "resourceIdentifier": resource_identifier,
            "expirationDate": expiration_date,
            "suppressIndefinitely": suppress_indefinitely,
            "description": description,
            "clientRequestToken": client_request_token,
        },
    )


async def delete(hub, ctx, check_name: str, resource_identifier: Dict) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a Device Defender audit suppression.

    Args:
        check_name(str): An audit check name. Checks must be enabled for your account. (Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or use UpdateAccountAuditConfiguration to select which checks are enabled.).
        resource_identifier(Dict): Information that identifies the noncompliant resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.suppression.delete(
                ctx, check_name=value, resource_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.suppression.delete check_name=value, resource_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_audit_suppression",
        op_kwargs={"checkName": check_name, "resourceIdentifier": resource_identifier},
    )


async def describe(hub, ctx, check_name: str, resource_identifier: Dict) -> Dict:
    r"""
    **Autogenerated function**

     Gets information about a Device Defender audit suppression.

    Args:
        check_name(str): An audit check name. Checks must be enabled for your account. (Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or use UpdateAccountAuditConfiguration to select which checks are enabled.).
        resource_identifier(Dict): Information that identifies the noncompliant resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.suppression.describe(
                ctx, check_name=value, resource_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.suppression.describe check_name=value, resource_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_audit_suppression",
        op_kwargs={"checkName": check_name, "resourceIdentifier": resource_identifier},
    )


async def list_all(
    hub,
    ctx,
    check_name: str = None,
    resource_identifier: Dict = None,
    ascending_order: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Lists your Device Defender audit listings.

    Args:
        check_name(str, optional): An audit check name. Checks must be enabled for your account. (Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or use UpdateAccountAuditConfiguration to select which checks are enabled.). Defaults to None.
        resource_identifier(Dict, optional): Information that identifies the noncompliant resource. Defaults to None.
        ascending_order(bool, optional):  Determines whether suppressions are listed in ascending order by expiration date or not. If parameter isn't provided, ascendingOrder=true. . Defaults to None.
        next_token(str, optional):  The token for the next set of results. . Defaults to None.
        max_results(int, optional):  The maximum number of results to return at one time. The default is 25. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.suppression.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.suppression.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_audit_suppressions",
        op_kwargs={
            "checkName": check_name,
            "resourceIdentifier": resource_identifier,
            "ascendingOrder": ascending_order,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    check_name: str,
    resource_identifier: Dict,
    expiration_date: str = None,
    suppress_indefinitely: bool = None,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a Device Defender audit suppression.

    Args:
        check_name(str): An audit check name. Checks must be enabled for your account. (Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or use UpdateAccountAuditConfiguration to select which checks are enabled.).
        resource_identifier(Dict): Information that identifies the noncompliant resource.
        expiration_date(str, optional):  The expiration date (epoch timestamp in seconds) that you want the suppression to adhere to. . Defaults to None.
        suppress_indefinitely(bool, optional):  Indicates whether a suppression should exist indefinitely or not. . Defaults to None.
        description(str, optional):  The description of the audit suppression. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.suppression.update(
                ctx, check_name=value, resource_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.suppression.update check_name=value, resource_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_audit_suppression",
        op_kwargs={
            "checkName": check_name,
            "resourceIdentifier": resource_identifier,
            "expirationDate": expiration_date,
            "suppressIndefinitely": suppress_indefinitely,
            "description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    grok_classifier: Dict = None,
    xml_classifier: Dict = None,
    json_classifier: Dict = None,
    csv_classifier: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a classifier in the user's account. This can be a GrokClassifier, an XMLClassifier, a JsonClassifier, or a CsvClassifier, depending on which field of the request is present.

    Args:
        grok_classifier(Dict, optional): A GrokClassifier object specifying the classifier to create. Defaults to None.
        xml_classifier(Dict, optional): An XMLClassifier object specifying the classifier to create. Defaults to None.
        json_classifier(Dict, optional): A JsonClassifier object specifying the classifier to create. Defaults to None.
        csv_classifier(Dict, optional): A CsvClassifier object specifying the classifier to create. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.classifier.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.classifier.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_classifier",
        op_kwargs={
            "GrokClassifier": grok_classifier,
            "XMLClassifier": xml_classifier,
            "JsonClassifier": json_classifier,
            "CsvClassifier": csv_classifier,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a classifier from the Data Catalog.

    Args:
        name(str): Name of the classifier to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.classifier.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.classifier.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_classifier",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a classifier by name.

    Args:
        name(str): Name of the classifier to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.classifier.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.classifier.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="get_classifier", op_kwargs={"Name": name}
    )


async def get_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all classifier objects in the Data Catalog.

    Args:
        max_results(int, optional): The size of the list to return (optional). Defaults to None.
        next_token(str, optional): An optional continuation token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.classifier.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.classifier.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_classifiers",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    grok_classifier: Dict = None,
    xml_classifier: Dict = None,
    json_classifier: Dict = None,
    csv_classifier: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an existing classifier (a GrokClassifier, an XMLClassifier, a JsonClassifier, or a CsvClassifier, depending on which field is present).

    Args:
        grok_classifier(Dict, optional): A GrokClassifier object with updated fields. Defaults to None.
        xml_classifier(Dict, optional): An XMLClassifier object with updated fields. Defaults to None.
        json_classifier(Dict, optional): A JsonClassifier object with updated fields. Defaults to None.
        csv_classifier(Dict, optional): A CsvClassifier object with updated fields. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.classifier.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.classifier.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_classifier",
        op_kwargs={
            "GrokClassifier": grok_classifier,
            "XMLClassifier": xml_classifier,
            "JsonClassifier": json_classifier,
            "CsvClassifier": csv_classifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def create(hub, ctx, account_alias: str) -> None:
    r"""
    **Autogenerated function**

    Creates an alias for your account. For information about using an account alias, see Using an alias for your account ID in the IAM User Guide.

    Args:
        account_alias(str): The account alias to create. This parameter allows (through its regex pattern) a string of characters consisting of lowercase letters, digits, and dashes. You cannot start or finish with a dash, nor can you have two dashes in a row.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.account.alias.create(ctx, account_alias=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.account.alias.create account_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_account_alias",
        op_kwargs={"AccountAlias": account_alias},
    )


async def delete(hub, ctx, account_alias: str) -> None:
    r"""
    **Autogenerated function**

     Deletes the specified account alias. For information about using an Amazon Web Services account alias, see Using an alias for your account ID in the IAM User Guide.

    Args:
        account_alias(str): The name of the account alias to delete. This parameter allows (through its regex pattern) a string of characters consisting of lowercase letters, digits, and dashes. You cannot start or finish with a dash, nor can you have two dashes in a row.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.account.alias.delete(ctx, account_alias=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.account.alias.delete account_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_account_alias",
        op_kwargs={"AccountAlias": account_alias},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current provisioned-capacity quotas for your AWS account in a Region, both for the Region as a whole and for any one DynamoDB table that you create there. When you establish an AWS account, the account has initial quotas on the maximum read capacity units and write capacity units that you can provision across all of your DynamoDB tables in a given Region. Also, there are per-table quotas that apply when you create a table there. For more information, see Service, Account, and Table Quotas page in the Amazon DynamoDB Developer Guide. Although you can increase these quotas by filing a case at AWS Support Center, obtaining the increase is not instantaneous. The DescribeLimits action lets you write code to compare the capacity you are currently using to those quotas imposed by your account so that you have enough time to apply for an increase before you hit a quota. For example, you could use one of the AWS SDKs to do the following:   Call DescribeLimits for a particular Region to obtain your current account quotas on provisioned capacity there.   Create a variable to hold the aggregate read capacity units provisioned for all your tables in that Region, and one to hold the aggregate write capacity units. Zero them both.   Call ListTables to obtain a list of all your DynamoDB tables.   For each table name listed by ListTables, do the following:   Call DescribeTable with the table name.   Use the data returned by DescribeTable to add the read capacity units and write capacity units provisioned for the table itself to your variables.   If the table has one or more global secondary indexes (GSIs), loop over these GSIs and add their provisioned capacity values to your variables as well.     Report the account quotas for that Region returned by DescribeLimits, along with the total current provisioned capacity levels you have calculated.   This will let you see whether you are getting close to your account-level quotas. The per-table quotas apply only when you are creating a new table. They restrict the sum of the provisioned capacity of the new table itself and all its global secondary indexes. For existing tables and their GSIs, DynamoDB doesn't let you increase provisioned capacity extremely rapidly, but the only quota that applies is that the aggregate provisioned capacity over all your tables and GSIs cannot exceed either of the per-account quotas.   DescribeLimits should only be called periodically. You can expect throttling errors if you call it more than once in a minute.  The DescribeLimits Request element has no content.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.limit.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.limit.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="dynamodb", operation="describe_limits", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the registry permissions policy.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.registry.policy.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.registry.policy.delete
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ecr", operation="delete_registry_policy", op_kwargs={}
    )


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the permissions policy for a registry.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.registry.policy.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.registry.policy.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ecr", operation="get_registry_policy", op_kwargs={}
    )


async def put(hub, ctx, policy_text: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates the permissions policy for your registry. A registry policy is used to specify permissions for another AWS account and is used when configuring cross-account replication. For more information, see Registry permissions in the Amazon Elastic Container Registry User Guide.

    Args:
        policy_text(str): The JSON policy text to apply to your registry. The policy text follows the same format as IAM policy text. For more information, see Registry permissions in the Amazon Elastic Container Registry User Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.registry.policy.put(ctx, policy_text=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.registry.policy.put policy_text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="put_registry_policy",
        op_kwargs={"policyText": policy_text},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(hub, ctx, user_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the permissions boundary for the specified IAM user.  Deleting the permissions boundary for a user might increase its permissions by allowing the user to perform all the actions granted in its permissions policies.

    Args:
        user_name(str): The name (friendly name, not ARN) of the IAM user from which you want to remove the permissions boundary.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.permission_boundary.delete(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.permission_boundary.delete user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_user_permissions_boundary",
        op_kwargs={"UserName": user_name},
    )


async def put(hub, ctx, user_name: str, permissions_boundary: str) -> None:
    r"""
    **Autogenerated function**

    Adds or updates the policy that is specified as the IAM user's permissions boundary. You can use an Amazon Web Services managed policy or a customer managed policy to set the boundary for a user. Use the boundary to control the maximum permissions that the user can have. Setting a permissions boundary is an advanced feature that can affect the permissions for the user.  Policies that are used as permissions boundaries do not provide permissions. You must also attach a permissions policy to the user. To learn how the effective permissions for a user are evaluated, see IAM JSON policy evaluation logic in the IAM User Guide.

    Args:
        user_name(str): The name (friendly name, not ARN) of the IAM user for which you want to set the permissions boundary.
        permissions_boundary(str): The ARN of the policy that is used to set the permissions boundary for the user.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.permission_boundary.put(
                ctx, user_name=value, permissions_boundary=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.permission_boundary.put user_name=value, permissions_boundary=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="put_user_permissions_boundary",
        op_kwargs={"UserName": user_name, "PermissionsBoundary": permissions_boundary},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    resource_id: str,
    custom_metadata: Dict,
    authentication_token: str = None,
    version_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more custom properties to the specified resource (a folder, document, or version).

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        resource_id(str): The ID of the resource.
        version_id(str, optional): The ID of the version, if the custom metadata is being added to a document version. Defaults to None.
        custom_metadata(Dict): Custom metadata in the form of name-value pairs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.custom_metadata.create(
                ctx, resource_id=value, custom_metadata=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.custom_metadata.create resource_id=value, custom_metadata=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="create_custom_metadata",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "ResourceId": resource_id,
            "VersionId": version_id,
            "CustomMetadata": custom_metadata,
        },
    )


async def delete(
    hub,
    ctx,
    resource_id: str,
    authentication_token: str = None,
    version_id: str = None,
    keys: List = None,
    delete_all: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes custom metadata from the specified resource.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        resource_id(str): The ID of the resource, either a document or folder.
        version_id(str, optional): The ID of the version, if the custom metadata is being deleted from a document version. Defaults to None.
        keys(List, optional): List of properties to remove. Defaults to None.
        delete_all(bool, optional): Flag to indicate removal of all custom metadata properties from the specified resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.custom_metadata.delete(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.custom_metadata.delete resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="delete_custom_metadata",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "ResourceId": resource_id,
            "VersionId": version_id,
            "Keys": keys,
            "DeleteAll": delete_all,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, product_subscription_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables the integration of the specified product with Security Hub. After the integration is disabled, findings from that product are no longer sent to Security Hub.

    Args:
        product_subscription_arn(str): The ARN of the integrated product to disable the integration for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.import_finding.for_product.disable(
                ctx, product_subscription_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.import_finding.for_product.disable product_subscription_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="disable_import_findings_for_product",
        op_kwargs={"ProductSubscriptionArn": product_subscription_arn},
    )


async def enable(hub, ctx, product_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Enables the integration of a partner product with Security Hub. Integrated products send findings to Security Hub. When you enable a product integration, a permissions policy that grants permission for the product to send findings to Security Hub is applied.

    Args:
        product_arn(str): The ARN of the product to enable the integration for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.import_finding.for_product.enable(
                ctx, product_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.import_finding.for_product.enable product_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="enable_import_findings_for_product",
        op_kwargs={"ProductArn": product_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    export_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve status of one or more export tasks. You can retrieve the status of up to 100 export tasks.

    Args:
        export_ids(List, optional): One or more unique identifiers used to query the status of an export request. Defaults to None.
        filters(List, optional): One or more filters.    AgentId - ID of the agent whose collected data will be exported  . Defaults to None.
        max_results(int, optional): The maximum number of volume results returned by DescribeExportTasks in paginated output. When this parameter is used, DescribeExportTasks only returns maxResults results in a single page along with a nextToken response element. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeExportTasks request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.export.task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.export.task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="describe_export_tasks",
        op_kwargs={
            "exportIds": export_ids,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(
    hub,
    ctx,
    export_data_format: List = None,
    filters: List = None,
    start_time: str = None,
    end_time: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Begins the export of discovered data to an S3 bucket.  If you specify agentIds in a filter, the task exports up to 72 hours of detailed data collected by the identified Application Discovery Agent, including network, process, and performance details. A time range for exported agent data may be set by using startTime and endTime. Export of detailed agent data is limited to five concurrently running exports.   If you do not include an agentIds filter, summary data is exported that includes both AWS Agentless Discovery Connector data and summary data from AWS Discovery Agents. Export of summary data is limited to two exports per day.

    Args:
        export_data_format(List, optional): The file format for the returned export data. Default value is CSV. Note: The GRAPHML option has been deprecated. . Defaults to None.
        filters(List, optional): If a filter is present, it selects the single agentId of the Application Discovery Agent for which data is exported. The agentId can be found in the results of the DescribeAgents API or CLI. If no filter is present, startTime and endTime are ignored and exported data includes both Agentless Discovery Connector data and summary data from Application Discovery agents. . Defaults to None.
        start_time(str, optional): The start timestamp for exported data from the single Application Discovery Agent selected in the filters. If no value is specified, data is exported starting from the first data collected by the agent. Defaults to None.
        end_time(str, optional): The end timestamp for exported data from the single Application Discovery Agent selected in the filters. If no value is specified, exported data includes the most recent data collected by the agent. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.export.task.start(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.export.task.start
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="start_export_task",
        op_kwargs={
            "exportDataFormat": export_data_format,
            "filters": filters,
            "startTime": start_time,
            "endTime": end_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def select(
    hub,
    ctx,
    select_expression: str,
    next_token: str = None,
    consistent_read: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The Select operation returns a set of attributes for ItemNames that match the select expression. Select is similar to the standard SQL SELECT statement.   The total size of the response cannot exceed 1 MB in total size. Amazon SimpleDB automatically adjusts the number of items returned per page to enforce this limit. For example, if the client asks to retrieve 2500 items, but each individual item is 10 kB in size, the system returns 100 items and an appropriate NextToken so the client can access the next page of results.   For information on how to construct select expressions, see Using Select to Create Amazon SimpleDB Queries in the Developer Guide.

    Args:
        select_expression(str): The expression used to query the domain.
        next_token(str, optional): A string informing Amazon SimpleDB where to start the next list of ItemNames. Defaults to None.
        consistent_read(bool, optional): Determines whether or not strong consistency should be enforced when data is read from SimpleDB. If true, any data previously written to SimpleDB will be returned. Otherwise, results will be consistent eventually, and the client may not see data that was written immediately before your read. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sdb.init.select(ctx, select_expression=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sdb.init.select select_expression=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sdb",
        operation="select",
        op_kwargs={
            "SelectExpression": select_expression,
            "NextToken": next_token,
            "ConsistentRead": consistent_read,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    image_id: str,
    bucket: str,
    s3_object_tags: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Stores an AMI as a single object in an S3 bucket. To use this API, you must have the required permissions. For more information, see Permissions for storing and restoring AMIs using S3 in the Amazon Elastic Compute Cloud User Guide. For more information, see Store and restore an AMI using S3 in the Amazon Elastic Compute Cloud User Guide.

    Args:
        image_id(str): The ID of the AMI.
        bucket(str): The name of the S3 bucket in which the AMI object will be stored. The bucket must be in the Region in which the request is being made. The AMI object appears in the bucket only after the upload task has completed. .
        s3_object_tags(List, optional): The tags to apply to the AMI object that will be stored in the S3 bucket. . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.store_image_task.create(ctx, image_id=value, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.store_image_task.create image_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_store_image_task",
        op_kwargs={
            "ImageId": image_id,
            "Bucket": bucket,
            "S3ObjectTags": s3_object_tags,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    image_ids: List = None,
    dry_run: bool = None,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the progress of the AMI store tasks. You can describe the store tasks for specified AMIs. If you don't specify the AMIs, you get a paginated list of store tasks from the last 31 days. For each AMI task, the response indicates if the task is InProgress, Completed, or Failed. For tasks InProgress, the response shows the estimated progress as a percentage. Tasks are listed in reverse chronological order. Currently, only tasks from the past 31 days can be viewed. To use this API, you must have the required permissions. For more information, see Permissions for storing and restoring AMIs using S3 in the Amazon Elastic Compute Cloud User Guide. For more information, see Store and restore an AMI using S3 in the Amazon Elastic Compute Cloud User Guide.

    Args:
        image_ids(List, optional): The AMI IDs for which to show progress. Up to 20 AMI IDs can be included in a request. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): The filters.    task-state - Returns tasks in a certain state (InProgress | Completed | Failed)    bucket - Returns task information for tasks that targeted a specific bucket. For the filter value, specify the bucket name.  . Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 1 and 200. You cannot specify this parameter and the ImageIDs parameter in the same call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.store_image_task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.store_image_task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_store_image_tasks",
        op_kwargs={
            "ImageIds": image_ids,
            "DryRun": dry_run,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    project_name: str,
    branch_filter: str = None,
    filter_groups: List = None,
    build_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, enables AWS CodeBuild to start rebuilding the source code every time a code change is pushed to the repository.  If you enable webhooks for an AWS CodeBuild project, and the project is used as a build step in AWS CodePipeline, then two identical builds are created for each commit. One build is triggered through webhooks, and one through AWS CodePipeline. Because billing is on a per-build basis, you are billed for both builds. Therefore, if you are using AWS CodePipeline, we recommend that you disable webhooks in AWS CodeBuild. In the AWS CodeBuild console, clear the Webhook box. For more information, see step 5 in Change a Build Project's Settings.

    Args:
        project_name(str): The name of the AWS CodeBuild project.
        branch_filter(str, optional): A regular expression used to determine which repository branches are built when a webhook is triggered. If the name of a branch matches the regular expression, then it is built. If branchFilter is empty, then all branches are built.  It is recommended that you use filterGroups instead of branchFilter.  . Defaults to None.
        filter_groups(List, optional): An array of arrays of WebhookFilter objects used to determine which webhooks are triggered. At least one WebhookFilter in the array must specify EVENT as its type.  For a build to be triggered, at least one filter group in the filterGroups array must pass. For a filter group to pass, each of its filters must pass. . Defaults to None.
        build_type(str, optional): Specifies the type of build this webhook will trigger. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.webhook.create(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.webhook.create project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="create_webhook",
        op_kwargs={
            "projectName": project_name,
            "branchFilter": branch_filter,
            "filterGroups": filter_groups,
            "buildType": build_type,
        },
    )


async def delete(hub, ctx, project_name: str) -> Dict:
    r"""
    **Autogenerated function**

    For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, stops AWS CodeBuild from rebuilding the source code every time a code change is pushed to the repository.

    Args:
        project_name(str): The name of the AWS CodeBuild project.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.webhook.delete(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.webhook.delete project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="delete_webhook",
        op_kwargs={"projectName": project_name},
    )


async def update(
    hub,
    ctx,
    project_name: str,
    branch_filter: str = None,
    rotate_secret: bool = None,
    filter_groups: List = None,
    build_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates the webhook associated with an AWS CodeBuild build project.    If you use Bitbucket for your repository, rotateSecret is ignored.

    Args:
        project_name(str): The name of the AWS CodeBuild project.
        branch_filter(str, optional): A regular expression used to determine which repository branches are built when a webhook is triggered. If the name of a branch matches the regular expression, then it is built. If branchFilter is empty, then all branches are built.   It is recommended that you use filterGroups instead of branchFilter.  . Defaults to None.
        rotate_secret(bool, optional):  A boolean value that specifies whether the associated GitHub repository's secret token should be updated. If you use Bitbucket for your repository, rotateSecret is ignored. . Defaults to None.
        filter_groups(List, optional):  An array of arrays of WebhookFilter objects used to determine if a webhook event can trigger a build. A filter group must contain at least one EVENT WebhookFilter. . Defaults to None.
        build_type(str, optional): Specifies the type of build this webhook will trigger. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.webhook.update(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.webhook.update project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="update_webhook",
        op_kwargs={
            "projectName": project_name,
            "branchFilter": branch_filter,
            "rotateSecret": rotate_secret,
            "filterGroups": filter_groups,
            "buildType": build_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    channel_id: str,
    id_: str,
    authorization: Dict = None,
    cmaf_package: Dict = None,
    dash_package: Dict = None,
    description: str = None,
    hls_package: Dict = None,
    manifest_name: str = None,
    mss_package: Dict = None,
    origination: str = None,
    startover_window_seconds: int = None,
    tags: Dict = None,
    time_delay_seconds: int = None,
    whitelist: List = None,
) -> Dict:
    r"""
        **Autogenerated function**

        Creates a new OriginEndpoint record.

        Args:
            authorization(Dict, optional): CDN Authorization credentials. Defaults to None.
            channel_id(str): The ID of the Channel that the OriginEndpoint will be associated with.
    This cannot be changed after the OriginEndpoint is created.
    .
            cmaf_package(Dict, optional): A Common Media Application Format (CMAF) packaging configuration. Defaults to None.
            dash_package(Dict, optional): A Dynamic Adaptive Streaming over HTTP (DASH) packaging configuration. Defaults to None.
            description(str, optional): A short text description of the OriginEndpoint. Defaults to None.
            hls_package(Dict, optional): An HTTP Live Streaming (HLS) packaging configuration. Defaults to None.
            id_(str): The ID of the OriginEndpoint.  The ID must be unique within the region
    and it cannot be changed after the OriginEndpoint is created.
    .
            manifest_name(str, optional): A short string that will be used as the filename of the OriginEndpoint URL (defaults to "index"). Defaults to None.
            mss_package(Dict, optional): A Microsoft Smooth Streaming (MSS) packaging configuration. Defaults to None.
            origination(str, optional): Control whether origination of video is allowed for this OriginEndpoint. If set to ALLOW, the OriginEndpoint
    may by requested, pursuant to any other form of access control. If set to DENY, the OriginEndpoint may not be
    requested. This can be helpful for Live to VOD harvesting, or for temporarily disabling origination
    . Defaults to None.
            startover_window_seconds(int, optional): Maximum duration (seconds) of content to retain for startover playback.
    If not specified, startover playback will be disabled for the OriginEndpoint.
    . Defaults to None.
            tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.
            time_delay_seconds(int, optional): Amount of delay (seconds) to enforce on the playback of live content.
    If not specified, there will be no time delay in effect for the OriginEndpoint.
    . Defaults to None.
            whitelist(List, optional): A list of source IP CIDR blocks that will be allowed to access the OriginEndpoint. Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.mediapackage.origin_endpoint.create(
                    ctx, channel_id=value, id_=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.mediapackage.origin_endpoint.create channel_id=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="create_origin_endpoint",
        op_kwargs={
            "Authorization": authorization,
            "ChannelId": channel_id,
            "CmafPackage": cmaf_package,
            "DashPackage": dash_package,
            "Description": description,
            "HlsPackage": hls_package,
            "Id": id_,
            "ManifestName": manifest_name,
            "MssPackage": mss_package,
            "Origination": origination,
            "StartoverWindowSeconds": startover_window_seconds,
            "Tags": tags,
            "TimeDelaySeconds": time_delay_seconds,
            "Whitelist": whitelist,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing OriginEndpoint.

    Args:
        id_(str): The ID of the OriginEndpoint to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage.origin_endpoint.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage.origin_endpoint.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="delete_origin_endpoint",
        op_kwargs={"Id": id_},
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets details about an existing OriginEndpoint.

    Args:
        id_(str): The ID of the OriginEndpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage.origin_endpoint.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage.origin_endpoint.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="describe_origin_endpoint",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub, ctx, channel_id: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a collection of OriginEndpoint records.

    Args:
        channel_id(str, optional): When specified, the request will return only OriginEndpoints associated with the given Channel ID. Defaults to None.
        max_results(int, optional): The upper bound on the number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage.origin_endpoint.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage.origin_endpoint.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="list_origin_endpoints",
        op_kwargs={
            "ChannelId": channel_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    id_: str,
    authorization: Dict = None,
    cmaf_package: Dict = None,
    dash_package: Dict = None,
    description: str = None,
    hls_package: Dict = None,
    manifest_name: str = None,
    mss_package: Dict = None,
    origination: str = None,
    startover_window_seconds: int = None,
    time_delay_seconds: int = None,
    whitelist: List = None,
) -> Dict:
    r"""
        **Autogenerated function**

        Updates an existing OriginEndpoint.

        Args:
            authorization(Dict, optional): CDN Authorization credentials. Defaults to None.
            cmaf_package(Dict, optional): A Common Media Application Format (CMAF) packaging configuration. Defaults to None.
            dash_package(Dict, optional): A Dynamic Adaptive Streaming over HTTP (DASH) packaging configuration. Defaults to None.
            description(str, optional): A short text description of the OriginEndpoint. Defaults to None.
            hls_package(Dict, optional): An HTTP Live Streaming (HLS) packaging configuration. Defaults to None.
            id_(str): The ID of the OriginEndpoint to update.
            manifest_name(str, optional): A short string that will be appended to the end of the Endpoint URL. Defaults to None.
            mss_package(Dict, optional): A Microsoft Smooth Streaming (MSS) packaging configuration. Defaults to None.
            origination(str, optional): Control whether origination of video is allowed for this OriginEndpoint. If set to ALLOW, the OriginEndpoint
    may by requested, pursuant to any other form of access control. If set to DENY, the OriginEndpoint may not be
    requested. This can be helpful for Live to VOD harvesting, or for temporarily disabling origination
    . Defaults to None.
            startover_window_seconds(int, optional): Maximum duration (in seconds) of content to retain for startover playback.
    If not specified, startover playback will be disabled for the OriginEndpoint.
    . Defaults to None.
            time_delay_seconds(int, optional): Amount of delay (in seconds) to enforce on the playback of live content.
    If not specified, there will be no time delay in effect for the OriginEndpoint.
    . Defaults to None.
            whitelist(List, optional): A list of source IP CIDR blocks that will be allowed to access the OriginEndpoint. Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.mediapackage.origin_endpoint.update(ctx, id_=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.mediapackage.origin_endpoint.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="update_origin_endpoint",
        op_kwargs={
            "Authorization": authorization,
            "CmafPackage": cmaf_package,
            "DashPackage": dash_package,
            "Description": description,
            "HlsPackage": hls_package,
            "Id": id_,
            "ManifestName": manifest_name,
            "MssPackage": mss_package,
            "Origination": origination,
            "StartoverWindowSeconds": startover_window_seconds,
            "TimeDelaySeconds": time_delay_seconds,
            "Whitelist": whitelist,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, policy_id: str, delete_all_policy_resources: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Permanently deletes an Firewall Manager policy.

    Args:
        policy_id(str): The ID of the policy that you want to delete. You can retrieve this ID from PutPolicy and ListPolicies.
        delete_all_policy_resources(bool, optional): If True, the request performs cleanup according to the policy type.  For WAF and Shield Advanced policies, the cleanup does the following:   Deletes rule groups created by Firewall Manager   Removes web ACLs from in-scope resources   Deletes web ACLs that contain no rules or rule groups   For security group policies, the cleanup does the following for each security group in the policy:   Disassociates the security group from in-scope resources    Deletes the security group if it was created through Firewall Manager and if it's no longer associated with any resources through another policy   After the cleanup, in-scope resources are no longer protected by web ACLs in this policy. Protection of out-of-scope resources remains unchanged. Scope is determined by tags that you create and accounts that you associate with the policy. When creating the policy, if you specify that only resources in specific accounts or with specific tags are in scope of the policy, those accounts and resources are handled by the policy. All others are out of scope. If you don't specify tags or accounts, all resources are in scope. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.policy.delete(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.policy.delete policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="delete_policy",
        op_kwargs={
            "PolicyId": policy_id,
            "DeleteAllPolicyResources": delete_all_policy_resources,
        },
    )


async def get(hub, ctx, policy_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified Firewall Manager policy.

    Args:
        policy_id(str): The ID of the Firewall Manager policy that you want the details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.policy.get(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.policy.get policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="get_policy",
        op_kwargs={"PolicyId": policy_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of PolicySummary objects.

    Args:
        next_token(str, optional): If you specify a value for MaxResults and you have more PolicySummary objects than the number that you specify for MaxResults, Firewall Manager returns a NextToken value in the response that allows you to list another group of PolicySummary objects. For the second and subsequent ListPolicies requests, specify the value of NextToken from the previous response to get information about another batch of PolicySummary objects. Defaults to None.
        max_results(int, optional): Specifies the number of PolicySummary objects that you want Firewall Manager to return for this request. If you have more PolicySummary objects than the number that you specify for MaxResults, the response includes a NextToken value that you can use to get another batch of PolicySummary objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.policy.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.policy.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="list_policies",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def put(hub, ctx, policy: Dict, tag_list: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Firewall Manager policy. Firewall Manager provides the following types of policies:    An WAF policy (type WAFV2), which defines rule groups to run first in the corresponding WAF web ACL and rule groups to run last in the web ACL.   An WAF Classic policy (type WAF), which defines a rule group.    A Shield Advanced policy, which applies Shield Advanced protection to specified accounts and resources.   A security group policy, which manages VPC security groups across your Amazon Web Services organization.    An Network Firewall policy, which provides firewall rules to filter network traffic in specified Amazon VPCs.   A DNS Firewall policy, which provides Route 53 Resolver DNS Firewall rules to filter DNS queries for specified VPCs.   Each policy is specific to one of the types. If you want to enforce more than one policy type across accounts, create multiple policies. You can create multiple policies for each type. You must be subscribed to Shield Advanced to create a Shield Advanced policy. For more information about subscribing to Shield Advanced, see CreateSubscription.

    Args:
        policy(Dict): The details of the Firewall Manager policy to be created.
        tag_list(List, optional): The tags to add to the Amazon Web Services resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.policy.put(ctx, policy=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.policy.put policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="put_policy",
        op_kwargs={"Policy": policy, "TagList": tag_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    sync_name: str = None,
    filters: List = None,
    aggregators: List = None,
    result_attributes: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    View a summary of operations metadata (OpsData) based on specified filters and aggregators. OpsData can include information about Amazon Web Services Systems Manager OpsCenter operational workitems (OpsItems) as well as information about any Amazon Web Services resource or service configured to report OpsData to Amazon Web Services Systems Manager Explorer.

    Args:
        sync_name(str, optional): Specify the name of a resource data sync to get. Defaults to None.
        filters(List, optional): Optional filters used to scope down the returned OpsData. . Defaults to None.
        aggregators(List, optional): Optional aggregators that return counts of OpsData based on one or more expressions. Defaults to None.
        result_attributes(List, optional): The OpsData data type to return. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.summary.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.summary.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_ops_summary",
        op_kwargs={
            "SyncName": sync_name,
            "Filters": filters,
            "Aggregators": aggregators,
            "ResultAttributes": result_attributes,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, bot_id: str, bot_alias_id: str, locale_id: str, session_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Removes session information for a specified bot, alias, and user ID.  You can use this operation to restart a conversation with a bot. When you remove a session, the entire history of the session is removed so that you can start again. You don't need to delete a session. Sessions have a time limit and will expire. Set the session time limit when you create the bot. The default is 5 minutes, but you can specify anything between 1 minute and 24 hours. If you specify a bot or alias ID that doesn't exist, you receive a BadRequestException.  If the locale doesn't exist in the bot, or if the locale hasn't been enables for the alias, you receive a BadRequestException.

    Args:
        bot_id(str): The identifier of the bot that contains the session data.
        bot_alias_id(str): The alias identifier in use for the bot that contains the session data.
        locale_id(str): The locale where the session is in use.
        session_id(str): The identifier of the session to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_runtime.session.delete(
                ctx, bot_id=value, bot_alias_id=value, locale_id=value, session_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_runtime.session.delete bot_id=value, bot_alias_id=value, locale_id=value, session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-runtime",
        operation="delete_session",
        op_kwargs={
            "botId": bot_id,
            "botAliasId": bot_alias_id,
            "localeId": locale_id,
            "sessionId": session_id,
        },
    )


async def get(
    hub, ctx, bot_id: str, bot_alias_id: str, locale_id: str, session_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Returns session information for a specified bot, alias, and user. For example, you can use this operation to retrieve session information for a user that has left a long-running session in use. If the bot, alias, or session identifier doesn't exist, Amazon Lex V2 returns a BadRequestException. If the locale doesn't exist or is not enabled for the alias, you receive a BadRequestException.

    Args:
        bot_id(str): The identifier of the bot that contains the session data.
        bot_alias_id(str): The alias identifier in use for the bot that contains the session data.
        locale_id(str): The locale where the session is in use.
        session_id(str): The identifier of the session to return.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_runtime.session.get(
                ctx, bot_id=value, bot_alias_id=value, locale_id=value, session_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_runtime.session.get bot_id=value, bot_alias_id=value, locale_id=value, session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-runtime",
        operation="get_session",
        op_kwargs={
            "botId": bot_id,
            "botAliasId": bot_alias_id,
            "localeId": locale_id,
            "sessionId": session_id,
        },
    )


async def put(
    hub,
    ctx,
    bot_id: str,
    bot_alias_id: str,
    locale_id: str,
    session_id: str,
    session_state: Dict,
    messages: List = None,
    request_attributes: Dict = None,
    response_content_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new session or modifies an existing session with an Amazon Lex V2 bot. Use this operation to enable your application to set the state of the bot.

    Args:
        bot_id(str): The identifier of the bot that receives the session data.
        bot_alias_id(str): The alias identifier of the bot that receives the session data.
        locale_id(str): The locale where the session is in use.
        session_id(str): The identifier of the session that receives the session data.
        messages(List, optional): A list of messages to send to the user. Messages are sent in the order that they are defined in the list. Defaults to None.
        session_state(Dict): Sets the state of the session with the user. You can use this to set the current intent, attributes, context, and dialog action. Use the dialog action to determine the next step that Amazon Lex V2 should use in the conversation with the user.
        request_attributes(Dict, optional): Request-specific information passed between Amazon Lex V2 and the client application. The namespace x-amz-lex: is reserved for special attributes. Don't create any request attributes with the prefix x-amz-lex:. Defaults to None.
        response_content_type(str, optional): The message that Amazon Lex V2 returns in the response can be either text or speech depending on the value of this parameter.    If the value is text/plain; charset=utf-8, Amazon Lex V2 returns text in the response.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_runtime.session.put(
                ctx,
                bot_id=value,
                bot_alias_id=value,
                locale_id=value,
                session_id=value,
                session_state=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_runtime.session.put bot_id=value, bot_alias_id=value, locale_id=value, session_id=value, session_state=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-runtime",
        operation="put_session",
        op_kwargs={
            "botId": bot_id,
            "botAliasId": bot_alias_id,
            "localeId": locale_id,
            "sessionId": session_id,
            "messages": messages,
            "sessionState": session_state,
            "requestAttributes": request_attributes,
            "responseContentType": response_content_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, aws_account_id: str, folder_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the folder resolved permissions. Permissions consists of both folder direct permissions and the inherited permissions from the ancestor folders.

    Args:
        aws_account_id(str): The AWS account ID.
        folder_id(str): The folder ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.folder.resolved_permission.describe_all(
                ctx, aws_account_id=value, folder_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.folder.resolved_permission.describe_all aws_account_id=value, folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_folder_resolved_permissions",
        op_kwargs={"AwsAccountId": aws_account_id, "FolderId": folder_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub, ctx, transit_gateway_attachment_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts a request to attach a VPC to a transit gateway. The VPC attachment must be in the pendingAcceptance state. Use DescribeTransitGatewayVpcAttachments to view your pending VPC attachment requests. Use RejectTransitGatewayVpcAttachment to reject a VPC attachment request.

    Args:
        transit_gateway_attachment_id(str): The ID of the attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.vpc_attachment.accept(
                ctx, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.vpc_attachment.accept transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="accept_transit_gateway_vpc_attachment",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )


async def create(
    hub,
    ctx,
    transit_gateway_id: str,
    vpc_id: str,
    subnet_ids: List,
    options: Dict = None,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches the specified VPC to the specified transit gateway. If you attach a VPC with a CIDR range that overlaps the CIDR range of a VPC that is already attached, the new VPC CIDR range is not propagated to the default propagation route table. To send VPC traffic to an attached transit gateway, add a route to the VPC route table using CreateRoute.

    Args:
        transit_gateway_id(str): The ID of the transit gateway.
        vpc_id(str): The ID of the VPC.
        subnet_ids(List): The IDs of one or more subnets. You can specify only one subnet per Availability Zone. You must specify at least one subnet, but we recommend that you specify two subnets for better availability. The transit gateway uses one IP address from each specified subnet.
        options(Dict, optional): The VPC attachment options. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the VPC attachment. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.vpc_attachment.create(
                ctx, transit_gateway_id=value, vpc_id=value, subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.vpc_attachment.create transit_gateway_id=value, vpc_id=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_transit_gateway_vpc_attachment",
        op_kwargs={
            "TransitGatewayId": transit_gateway_id,
            "VpcId": vpc_id,
            "SubnetIds": subnet_ids,
            "Options": options,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, transit_gateway_attachment_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified VPC attachment.

    Args:
        transit_gateway_attachment_id(str): The ID of the attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.vpc_attachment.delete(
                ctx, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.vpc_attachment.delete transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_transit_gateway_vpc_attachment",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    transit_gateway_attachment_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more VPC attachments. By default, all VPC attachments are described. Alternatively, you can filter the results.

    Args:
        transit_gateway_attachment_ids(List, optional): The IDs of the attachments. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    state - The state of the attachment. Valid values are available | deleted | deleting | failed | failing | initiatingRequest | modifying | pendingAcceptance | pending | rollingBack | rejected | rejecting.    transit-gateway-attachment-id - The ID of the attachment.    transit-gateway-id - The ID of the transit gateway.    vpc-id - The ID of the VPC.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.vpc_attachment.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.vpc_attachment.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_transit_gateway_vpc_attachments",
        op_kwargs={
            "TransitGatewayAttachmentIds": transit_gateway_attachment_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )


async def modify(
    hub,
    ctx,
    transit_gateway_attachment_id: str,
    add_subnet_ids: List = None,
    remove_subnet_ids: List = None,
    options: Dict = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified VPC attachment.

    Args:
        transit_gateway_attachment_id(str): The ID of the attachment.
        add_subnet_ids(List, optional): The IDs of one or more subnets to add. You can specify at most one subnet per Availability Zone. Defaults to None.
        remove_subnet_ids(List, optional): The IDs of one or more subnets to remove. Defaults to None.
        options(Dict, optional): The new VPC attachment options.  You cannot modify the IPv6 options. . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.vpc_attachment.modify(
                ctx, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.vpc_attachment.modify transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_transit_gateway_vpc_attachment",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "AddSubnetIds": add_subnet_ids,
            "RemoveSubnetIds": remove_subnet_ids,
            "Options": options,
            "DryRun": dry_run,
        },
    )


async def reject(
    hub, ctx, transit_gateway_attachment_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Rejects a request to attach a VPC to a transit gateway. The VPC attachment must be in the pendingAcceptance state. Use DescribeTransitGatewayVpcAttachments to view your pending VPC attachment requests. Use AcceptTransitGatewayVpcAttachment to accept a VPC attachment request.

    Args:
        transit_gateway_attachment_id(str): The ID of the attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.vpc_attachment.reject(
                ctx, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.vpc_attachment.reject transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reject_transit_gateway_vpc_attachment",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )
